@@ -1,6 +1,6 @@
 package Test::Mocha;
 # ABSTRACT: Test double framework with method stubs and behaviour verification
-$Test::Mocha::VERSION = '0.62_01';  # TRIAL
+$Test::Mocha::VERSION = '0.62_02';  # TRIAL
 
 use strict;
 use warnings;
@@ -66,15 +66,17 @@ sub stub (&@) {
           if ref ne 'CODE';
     }
 
-    # add stub to mock
-    my $method_call =
-      Test::Mocha::Mock->__capture_method_call( $coderef, 'stub' );
-    unshift @{ $method_call->invocant->__stubs->{ $method_call->name } },
-      $method_call;
+    my @method_calls =
+      Test::Mocha::Mock->__capture_method_calls( $coderef, 'stub' );
+    for my $method_call (@method_calls) {
+        # add stub to mock
+        unshift @{ $method_call->invocant->__stubs->{ $method_call->name } },
+          $method_call;
 
-    # add response to stub
-    Test::Mocha::MethodStub->cast($method_call);
-    push @{ $method_call->__responses }, @responses;
+        # add response to stub
+        Test::Mocha::MethodStub->cast($method_call);
+        push @{ $method_call->__responses }, @responses;
+    }
     return;
 }
 
@@ -116,13 +118,13 @@ sub called_ok (&;@) {
         $test_name = shift;
     }
 
-    my $method_call =
-      Test::Mocha::Mock->__capture_method_call( $coderef, 'verify' );
+    my @method_calls =
+      Test::Mocha::Mock->__capture_method_calls( $coderef, 'verify' );
 
     ## no critic (ProhibitAmpersandSigils)
     local $Test::Builder::Level = $Test::Builder::Level + 1;
     $called_ok ||= &times(1);  # default if no times() is specified
-    $called_ok->( $method_call, $test_name );
+    $called_ok->( $_, $test_name ) for @method_calls;
     return;
 }
 ## use critic
@@ -176,12 +178,16 @@ sub between ($$) {
 
 sub inspect (&) {
     my ($coderef) = @_;
-    my $method_call =
-      Test::Mocha::Mock->__capture_method_call( $coderef, 'inspect' );
+    my @method_calls =
+      Test::Mocha::Mock->__capture_method_calls( $coderef, 'inspect' );
 
-    return
-      grep { $method_call->__satisfied_by($_) }
-      @{ $method_call->invocant->__calls };
+    my @inspect;
+    foreach my $method_call (@method_calls) {
+        push @inspect,
+          grep { $method_call->__satisfied_by($_) }
+          @{ $method_call->invocant->__calls };
+    }
+    return @inspect;
 }
 
 sub inspect_all ($) {
@@ -258,7 +264,7 @@ Test::Mocha - Test double framework with method stubs and behaviour verification
 
 =head1 VERSION
 
-version 0.62_01
+version 0.62_02
 
 =head1 SYNOPSIS
 
@@ -427,6 +433,15 @@ The last stubbed response will persist until it is overridden.
     stub { $warehouse->has_inventory($item, 10) } returns '';
     print( $warehouse->has_inventory($item, 10) ) for 1 .. 5; # nothing printed
 
+You can apply a stub to multiple method calls in one go to set them with the
+same responses.
+
+    stub {
+        $mock1->method1(1);
+        $mock2->method2(1);
+        $spy->method3(2);
+    } returns(2), returns(1);
+
 =head2 called_ok
 
     called_ok { $mock->method(@args) }
@@ -496,6 +511,14 @@ of the default.
     called_ok { $warehouse->remove_inventory($item, 50) } times(0), 'inventory not removed';
     # prints "ok 2 - inventory not removed"
 
+You can verify multiple method calls in one go.
+
+    called_ok {
+        $mock1->method1(1);
+        $mock2->method2(1);
+        $spy->method3(2);
+    } times(2);
+
 =head2 inspect
 
     @method_calls = inspect { $mock->method(@args) };
