@@ -1,6 +1,6 @@
 package Test::Mocha::Mock;
 # ABSTRACT: Mock objects
-$Test::Mocha::Mock::VERSION = '0.62_01';  # TRIAL
+$Test::Mocha::Mock::VERSION = '0.62_02';  # TRIAL
 use parent 'Test::Mocha::SpyBase';
 use strict;
 use warnings;
@@ -102,8 +102,7 @@ sub AUTOLOAD {
     );
 
     if ( $self->__CaptureMode ) {
-        $self->__NumMethodCalls( $self->__NumMethodCalls + 1 );
-        $self->__LastMethodCall($method_call);
+        $self->__CaptureMethodCall($method_call);
         return;
     }
 
